==> kdebindings-3.3.2.tar.bz2: kdebindings-3.3.2/kjsembed/qtbindings/qcanvasrectangle_imp.cpp <==

  

#include <qcstring.h>
#include <qimage.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpixmap.h>
#include <qfont.h>

#include <kjs/object.h>

#include <kjsembed/global.h>
#include <kjsembed/jsobjectproxy.h>
#include <kjsembed/jsopaqueproxy.h>
#include <kjsembed/jsbinding.h>

#include <qcanvas.h>
#include "qcanvasrectangle_imp.h"

/**
 * Namespace containing the KJSEmbed library.
 */
namespace KJSEmbed {

QCanvasRectangleImp::QCanvasRectangleImp( KJS::ExecState *exec, int mid, bool constructor )
   : JSProxyImp(exec), id(mid), cons(constructor)
{
}

QCanvasRectangleImp::~QCanvasRectangleImp()
{
}

/**
 * Adds bindings for static methods and enum constants to the specified Object.
 */
void QCanvasRectangleImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
{
    JSProxy::MethodTable methods[] = {

	{ 0, 0 }
    };

    int idx = 0;
    QCString lastName;

    while( methods[idx].name ) {
        if ( lastName != methods[idx].name ) {
            QCanvasRectangleImp *meth = new QCanvasRectangleImp( exec, methods[idx].id );
            object.put( exec , methods[idx].name, KJS::Object(meth) );
            lastName = methods[idx].name;
        }
        ++idx;
    }


}

/**
 * Adds bindings for instance methods to the specified Object.
 */
void QCanvasRectangleImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
    JSProxy::MethodTable methods[] = {

        { Method_width_5, "width" },
        { Method_height_6, "height" },
        { Method_setSize_7, "setSize" },
        { Method_size_8, "size" },
        { Method_areaPoints_9, "areaPoints" },
        { Method_rect_10, "rect" },
        { Method_collidesWith_11, "collidesWith" },
        { Method_rtti_12, "rtti" },
	{ 0, 0 }
    };

    int idx = 0;
    QCString lastName;

    while( methods[idx].name ) {
        if ( lastName != methods[idx].name ) {
            QCanvasRectangleImp *meth = new QCanvasRectangleImp( exec, methods[idx].id );
            object.put( exec , methods[idx].name, KJS::Object(meth) );
            lastName = methods[idx].name;
        }
        ++idx;
    }
}

/**
 * Extract a QCanvasRectangle pointer from an Object.
 */
QCanvasRectangle *QCanvasRectangleImp::toQCanvasRectangle( KJS::Object &self )
{
    JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
    if ( ob ) {
        QObject *obj = ob->object();
	if ( obj )
           return dynamic_cast<QCanvasRectangle *>( obj );
    }

    JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
    if ( !op )
        return 0;

    if ( op->typeName() != "QCanvasRectangle" )
        return 0;

    return (QCanvasRectangle *)( op->toVoidStar() );
}

/**
 * Select and invoke the correct constructor.
 */
KJS::Object QCanvasRectangleImp::construct( KJS::ExecState *exec, const KJS::List &args )
{
   switch( id ) {

         case Constructor_QCanvasRectangle_1:
             return QCanvasRectangle_1( exec, args );
             break;
    
         case Constructor_QCanvasRectangle_2:
             return QCanvasRectangle_2( exec, args );
             break;
    
         case Constructor_QCanvasRectangle_3:
             return QCanvasRectangle_3( exec, args );
             break;
    
         default:
             break;
    }

    QString msg = i18n("QCanvasRectangleCons has no constructor with id '%1'.").arg(id);
    KJS::Object err = KJS::Error::create( exec, KJS::ReferenceError, msg.utf8() );
    exec->setException( err );
    return err;
}


KJS::Object QCanvasRectangleImp::QCanvasRectangle_1( KJS::ExecState *exec, const KJS::List &args )
{
    
    // Unsupported parameter QCanvas *
    return KJS::Object();
    
    QCanvas * arg0; // Dummy
        

    // We should now create an instance of the QCanvasRectangle object

    QCanvasRectangle *ret = new QCanvasRectangle(
       
          arg0 );

    
}
    
KJS::Object QCanvasRectangleImp::QCanvasRectangle_2( KJS::ExecState *exec, const KJS::List &args )
{
    
    QRect arg0 = extractQRect(exec, args, 0);
        
    // Unsupported parameter QCanvas *
    return KJS::Object();
    
    QCanvas * arg1; // Dummy
        

    // We should now create an instance of the QCanvasRectangle object

    QCanvasRectangle *ret = new QCanvasRectangle(
       
          arg0,
          arg1 );

    
}
    
KJS::Object QCanvasRectangleImp::QCanvasRectangle_3( KJS::ExecState *exec, const KJS::List &args )
{
    
    int arg0 = extractInt(exec, args, 0);
        
    int arg1 = extractInt(exec, args, 1);
        
    int arg2 = extractInt(exec, args, 2);
        
    int arg3 = extractInt(exec, args, 3);
        
    // Unsupported parameter QCanvas *
    return KJS::Object();
    
    QCanvas * arg4; // Dummy
        

    // We should now create an instance of the QCanvasRectangle object

    QCanvasRectangle *ret = new QCanvasRectangle(
       
          arg0,
          arg1,
          arg2,
          arg3,
          arg4 );

    
}
    
KJS::Value QCanvasRectangleImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
    instance = QCanvasRectangleImp::toQCanvasRectangle( self );

    switch( id ) {

    case Method_width_5:
        return width_5( exec, self, args );
        break;
    
    case Method_height_6:
        return height_6( exec, self, args );
        break;
    
    case Method_setSize_7:
        return setSize_7( exec, self, args );
        break;
    
    case Method_size_8:
        return size_8( exec, self, args );
        break;
    
    case Method_areaPoints_9:
        return areaPoints_9( exec, self, args );
        break;
    
    case Method_rect_10:
        return rect_10( exec, self, args );
        break;
    
    case Method_collidesWith_11:
        return collidesWith_11( exec, self, args );
        break;
    
    case Method_rtti_12:
        return rtti_12( exec, self, args );
        break;
    
    default:
        break;
    }

    QString msg = i18n( "QCanvasRectangleImp has no method with id '%1'." ).arg( id );
    KJS::Object err = KJS::Error::create( exec, KJS::ReferenceError, msg.utf8() );
    exec->setException( err );
    return err;
}


KJS::Value QCanvasRectangleImp::width_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
    
      int ret;
      ret = instance->width(  );
      return KJS::Number( ret );
      
}
    
KJS::Value QCanvasRectangleImp::height_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
    
      int ret;
      ret = instance->height(  );
      return KJS::Number( ret );
      
}
    
KJS::Value QCanvasRectangleImp::setSize_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
    
    int arg0 = extractInt(exec, args, 0);
        
    int arg1 = extractInt(exec, args, 1);
        
      instance->setSize( 
       arg0,
       arg1 );
      return KJS::Value(); // Returns void
      
}
    
KJS::Value QCanvasRectangleImp::size_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
    QSize ret;
      ret = instance->size(  );

       return convertToValue( exec, ret );
      
}
    
KJS::Value QCanvasRectangleImp::areaPoints_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
    
      instance->areaPoints(  );
      return KJS::Value(); // Returns 'QPointArray'
      
}
    
KJS::Value QCanvasRectangleImp::rect_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
    QRect ret;
      ret = instance->rect(  );

       return convertToValue( exec, ret );
      
}
    
KJS::Value QCanvasRectangleImp::collidesWith_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
    
    // Unsupported parameter const QCanvasItem *
    return KJS::Value();
    
    const QCanvasItem * arg0; // Dummy
        
      bool ret;
      ret = instance->collidesWith( 
       arg0 );
      return KJS::Boolean( ret );
      
}
    
KJS::Value QCanvasRectangleImp::rtti_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
    
      int ret;
      ret = instance->rtti(  );
      return KJS::Number( ret );
      
}
    

} // namespace KJSEmbed

// Local Variables:
// c-basic-offset: 4
// End:

==> kdebindings-3.5.10.tar.bz2: kdebindings-3.5.10/kjsembed/qtbindings/qcanvasrectangle_imp.cpp <==



#include <qcstring.h>
#include <qimage.h>
#include <qpainter.h>
#include <qpalette.h>
#include <qpixmap.h>
#include <qfont.h>

#include <kjs/object.h>

#include <kjsembed/global.h>
#include <kjsembed/jsobjectproxy.h>
#include <kjsembed/jsopaqueproxy.h>
#include <kjsembed/jsbinding.h>

#include <qcanvas.h>
#include "qcanvasrectangle_imp.h"

/**
 * Namespace containing the KJSEmbed library.
 */
namespace KJSEmbed {

QCanvasRectangleImp::QCanvasRectangleImp( KJS::ExecState *exec, int mid, bool constructor )
   : JSProxyImp(exec), id(mid), cons(constructor)
{
}

QCanvasRectangleImp::~QCanvasRectangleImp()
{
}

/**
 * Adds bindings for static methods and enum constants to the specified Object.
 */
void QCanvasRectangleImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
{
    JSProxy::MethodTable methods[] = {

	{ 0, 0 }
    };

    int idx = 0;
    QCString lastName;

    while( methods[idx].name ) {
        if ( lastName != methods[idx].name ) {
            QCanvasRectangleImp *meth = new QCanvasRectangleImp( exec, methods[idx].id );
            object.put( exec , methods[idx].name, KJS::Object(meth) );
            lastName = methods[idx].name;
        }
        ++idx;
    }


}

/**
 * Adds bindings for instance methods to the specified Object.
 */
void QCanvasRectangleImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
    JSProxy::MethodTable methods[] = {

        { Method_width_5, "width" },
        { Method_height_6, "height" },
        { Method_setSize_7, "setSize" },
        { Method_size_8, "size" },
        { Method_areaPoints_9, "areaPoints" },
        { Method_rect_10, "rect" },
        { Method_collidesWith_11, "collidesWith" },
        { Method_rtti_12, "rtti" },
	{ 0, 0 }
    };

    int idx = 0;
    QCString lastName;

    while( methods[idx].name ) {
        if ( lastName != methods[idx].name ) {
            QCanvasRectangleImp *meth = new QCanvasRectangleImp( exec, methods[idx].id );
            object.put( exec , methods[idx].name, KJS::Object(meth) );
            lastName = methods[idx].name;
        }
        ++idx;
    }
}

/**
 * Extract a QCanvasRectangle pointer from an Object.
 */
QCanvasRectangle *QCanvasRectangleImp::toQCanvasRectangle( KJS::Object &self )
{
    JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
    if ( ob ) {
        QObject *obj = ob->object();
	if ( obj )
           return dynamic_cast<QCanvasRectangle *>( obj );
    }

    JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
    if ( !op )
        return 0;

    if ( op->typeName() != "QCanvasRectangle" )
        return 0;

    return op->toNative<QCanvasRectangle>();
}

/**
 * Select and invoke the correct constructor.
 */
KJS::Object QCanvasRectangleImp::construct( KJS::ExecState *exec, const KJS::List &args )
{
   switch( id ) {

         case Constructor_QCanvasRectangle_1:
             return QCanvasRectangle_1( exec, args );
             break;

         case Constructor_QCanvasRectangle_2:
             return QCanvasRectangle_2( exec, args );
             break;

         case Constructor_QCanvasRectangle_3:
             return QCanvasRectangle_3( exec, args );
             break;

         default:
             break;
    }

    QString msg = i18n("QCanvasRectangleCons has no constructor with id '%1'.").arg(id);
    return throwError(exec, msg,KJS::ReferenceError);
}


KJS::Object QCanvasRectangleImp::QCanvasRectangle_1( KJS::ExecState *exec, const KJS::List &args )
{

    // Unsupported parameter QCanvas *
    return KJS::Object();

    QCanvas * arg0; // Dummy


    // We should now create an instance of the QCanvasRectangle object

    QCanvasRectangle *ret = new QCanvasRectangle(

          arg0 );


}

KJS::Object QCanvasRectangleImp::QCanvasRectangle_2( KJS::ExecState *exec, const KJS::List &args )
{

    QRect arg0 = extractQRect(exec, args, 0);

    // Unsupported parameter QCanvas *
    return KJS::Object();

    QCanvas * arg1; // Dummy


    // We should now create an instance of the QCanvasRectangle object

    QCanvasRectangle *ret = new QCanvasRectangle(

          arg0,
          arg1 );


}

KJS::Object QCanvasRectangleImp::QCanvasRectangle_3( KJS::ExecState *exec, const KJS::List &args )
{

    int arg0 = extractInt(exec, args, 0);

    int arg1 = extractInt(exec, args, 1);

    int arg2 = extractInt(exec, args, 2);

    int arg3 = extractInt(exec, args, 3);

    // Unsupported parameter QCanvas *
    return KJS::Object();

    QCanvas * arg4; // Dummy


    // We should now create an instance of the QCanvasRectangle object

    QCanvasRectangle *ret = new QCanvasRectangle(

          arg0,
          arg1,
          arg2,
          arg3,
          arg4 );


}

KJS::Value QCanvasRectangleImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
    instance = QCanvasRectangleImp::toQCanvasRectangle( self );

    switch( id ) {

    case Method_width_5:
        return width_5( exec, self, args );
        break;

    case Method_height_6:
        return height_6( exec, self, args );
        break;

    case Method_setSize_7:
        return setSize_7( exec, self, args );
        break;

    case Method_size_8:
        return size_8( exec, self, args );
        break;

    case Method_areaPoints_9:
        return areaPoints_9( exec, self, args );
        break;

    case Method_rect_10:
        return rect_10( exec, self, args );
        break;

    case Method_collidesWith_11:
        return collidesWith_11( exec, self, args );
        break;

    case Method_rtti_12:
        return rtti_12( exec, self, args );
        break;

    default:
        break;
    }

    QString msg = i18n( "QCanvasRectangleImp has no method with id '%1'." ).arg( id );
    return throwError(exec, msg,KJS::ReferenceError);
}


KJS::Value QCanvasRectangleImp::width_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{

      int ret;
      ret = instance->width(  );
      return KJS::Number( ret );

}

KJS::Value QCanvasRectangleImp::height_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{

      int ret;
      ret = instance->height(  );
      return KJS::Number( ret );

}

KJS::Value QCanvasRectangleImp::setSize_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{

    int arg0 = extractInt(exec, args, 0);

    int arg1 = extractInt(exec, args, 1);

      instance->setSize(
       arg0,
       arg1 );
      return KJS::Value(); // Returns void

}

KJS::Value QCanvasRectangleImp::size_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
    QSize ret;
      ret = instance->size(  );

       return convertToValue( exec, ret );

}

KJS::Value QCanvasRectangleImp::areaPoints_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{

      instance->areaPoints(  );
      return KJS::Value(); // Returns 'QPointArray'

}

KJS::Value QCanvasRectangleImp::rect_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
    QRect ret;
      ret = instance->rect(  );

       return convertToValue( exec, ret );

}

KJS::Value QCanvasRectangleImp::collidesWith_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{

    // Unsupported parameter const QCanvasItem *
    return KJS::Value();

    const QCanvasItem * arg0; // Dummy

      bool ret;
      ret = instance->collidesWith(
       arg0 );
      return KJS::Boolean( ret );

}

KJS::Value QCanvasRectangleImp::rtti_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{

      int ret;
      ret = instance->rtti(  );
      return KJS::Number( ret );

}


} // namespace KJSEmbed

// Local Variables:
// c-basic-offset: 4
// End:
